@@ -1,15 +1,15 @@
 import tensorflow as tf
-from tensorflow.keras import layers
+from tensorflow.keras import layers as tf_layers
 
 
-class RBFExpansion(layers.Layer):
+class RBFExpansion(tf_layers.Layer):
     def __init__(self,
                  dimension=128,
                  init_gap=10,
                  init_max_distance=7,
                  trainable=False):
         """ Layer to calculate radial basis function 'embeddings' for a continuous input variable. The width and
-        location of each bin can be optionally trained. Essentially equivalent to a 1-hot embedding for a continous
+        location of each bin can be optionally trained. Essentially equivalent to a 1-hot embedding for a continuous
         variable.
 
         Parameters
@@ -28,10 +28,9 @@ class RBFExpansion(layers.Layer):
     def build(self, input_shape):
         self.centers = tf.Variable(
             name='centers',
-            initial_value=tf.range(0,
-                                   self.init_max_distance,
-                                   delta=self.init_max_distance /
-                                   self.dimension),
+            initial_value=tf.range(
+                0, self.init_max_distance,
+                delta=self.init_max_distance / self.dimension),
             trainable=self.trainable,
             dtype=tf.float32)
 
@@ -46,7 +45,7 @@ class RBFExpansion(layers.Layer):
                              tf.zeros_like(inputs, dtype=inputs.dtype), inputs)
         offset = tf.expand_dims(distances, -1) - tf.cast(
             self.centers, inputs.dtype)
-        logits = -self.gap * offset**2
+        logits = -self.gap * offset ** 2
         return tf.exp(logits)
 
     def compute_mask(self, inputs, mask=None):
@@ -99,7 +98,7 @@ def batched_segment_op(data,
     return tf.reshape(reduced_data, [batch_size, num_segments, data.shape[-1]])
 
 
-# class Slice(layers.Layer):
+# class Slice(tf_layers.Layer):
 #     def __init__(self, slice_obj, *args, **kwargs):
 #         super(Slice, self).__init__(*args, **kwargs)
 #         self.slice_obj = slice_obj
@@ -117,33 +116,22 @@ def batched_segment_op(data,
 #         return cls(**config)
 
 
-class Gather(layers.Layer):
-    def call(self, inputs, mask=None):
+class Gather(tf_layers.Layer):
+    def call(self, inputs, mask=None, **kwargs):
         reference, indices = inputs
         return tf.gather(reference, indices, batch_dims=1)
 
 
-class Reduce(layers.Layer):
+class Reduce(tf_layers.Layer):
     def __init__(self, reduction='sum', *args, **kwargs):
         super(Reduce, self).__init__(*args, **kwargs)
         self.reduction = reduction
 
-    def _parse_inputs_and_mask(self, inputs, mask=None):
-        data, segment_ids, target = inputs
-
-        # Handle missing masks
-        if mask is not None:
-            data_mask = mask[0]
-        else:
-            data_mask = None
-
-        return data, segment_ids, target, data_mask
-
     def compute_output_shape(self, input_shape):
         data_shape, _, target_shape = input_shape
         return [data_shape[0], target_shape[1], data_shape[-1]]
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         data, segment_ids, target, data_mask = self._parse_inputs_and_mask(
             inputs, mask)
         num_segments = tf.shape(target, out_type=segment_ids.dtype)[1]
@@ -156,21 +144,34 @@ class Reduce(layers.Layer):
     def get_config(self):
         return {'reduction': self.reduction}
 
+    @staticmethod
+    def _parse_inputs_and_mask(inputs, mask=None):
+        data, segment_ids, target = inputs
 
-class ConcatDense(layers.Layer):
+        # Handle missing masks
+        if mask is not None:
+            data_mask = mask[0]
+        else:
+            data_mask = None
+
+        return data, segment_ids, target, data_mask
+
+
+class ConcatDense(tf_layers.Layer):
     """ Layer to combine the concatenation and two dense layers. Just useful as a common operation in the graph
     layers """
+
     def __init__(self, **kwargs):
         super(ConcatDense, self).__init__(**kwargs)
         self.supports_masking = True
 
     def build(self, input_shape):
         num_features = input_shape[0][-1]
-        self.concat = layers.Concatenate()
-        self.dense1 = layers.Dense(2 * num_features, activation='relu')
-        self.dense2 = layers.Dense(num_features)
+        self.concat = tf_layers.Concatenate()
+        self.dense1 = tf_layers.Dense(2 * num_features, activation='relu')
+        self.dense2 = tf_layers.Dense(num_features)
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         output = self.concat(inputs)
         output = self.dense1(output)
         output = self.dense2(output)
@@ -183,12 +184,12 @@ class ConcatDense(layers.Layer):
             return tf.math.reduce_all(tf.stack(mask), axis=0)
 
 
-class Tile(layers.Layer):
+class Tile(tf_layers.Layer):
     def __init__(self, **kwargs):
         super(Tile, self).__init__(**kwargs)
         self.supports_masking = True
 
-    def call(self, inputs, mask=None):
+    def call(self, inputs, mask=None, **kwargs):
         global_state, target = inputs
         target_shape = tf.shape(target)[1]  # number of edges or nodes
         expanded = tf.expand_dims(global_state, 1)
